# Tutorial

The following tutorials represent the two approaches to using PLINDER:
The files from the dataset can be accessed directly using your preferred tooling.
On the other side, the dedicated `plinder` Python package provides a simplified
efficient way for working with the data.

```{toctree}
:maxdepth: 1

dataset
api
```
